# types-awscrt

[![PyPI - types-awscrt](https://img.shields.io/pypi/v/types-awscrt.svg?color=blue&label=types-awscrt)](https://pypi.org/project/types-awscrt)
[![PyPI - awscrt](https://img.shields.io/pypi/v/awscrt.svg?color=blue&label=awscrt)](https://pypi.org/project/awscrt)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-awscrt.svg?color=blue)](https://pypi.org/project/types-awscrt)
[![PyPI - Downloads](https://static.pepy.tech/badge/types-awscrt)](https://pepy.tech/project/types-awscrt)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations and code completion for [awscrt](https://pypi.org/project/awscrt/) package.
This package is a part of [mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder) project.

[![Publish botocore-stubs](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml)
[![Publish types-awscrt](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml)
[![Publish types-s3transfer](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml)

- [types-awscrt](#types-awscrt)
  - [Installation](#installation)
  - [Usage](#usage)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Support and contributing](#support-and-contributing)


## Installation

```bash
python -m pip install types-awscrt
```

## Usage

Use [mypy](https://github.com/python/mypy) or [pyright](https://github.com/microsoft/pyright) for type checking.

### Latest changes

Full changelog can be found in [Releases](https://github.com/youtype/types-awscrt/releases).

## Versioning

`types-awscrt` version is the same as related `awscrt` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Support and contributing

Please reports any bugs or request new features in
[types-awscrt](https://github.com/youtype/types-awscrt/issues/) repository.
